@@ -17,6 +17,7 @@
 # under the License.
 from __future__ import annotations
 
+from functools import cached_property
 from typing import TYPE_CHECKING, ClassVar, Collection, Sequence
 
 import attr
@@ -24,6 +25,7 @@ import papermill as pm
 
 from airflow.lineage.entities import File
 from airflow.models import BaseOperator
+from airflow.providers.papermill.hooks.kernel import REMOTE_KERNEL_ENGINE, KernelHook
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -33,14 +35,7 @@ if TYPE_CHECKING:
 class NoteBook(File):
     """Jupyter notebook."""
 
-    # For compatibility with Airflow 2.3:
-    # 1. Use predefined set because `File.template_fields` introduced in Airflow 2.4
-    # 2. Use old styled annotations because `cattrs` doesn't work well with PEP 604.
-
-    template_fields: ClassVar[Collection[str]] = {
-        "parameters",
-        *(File.template_fields if hasattr(File, "template_fields") else {"url"}),
-    }
+    template_fields: ClassVar[Collection[str]] = {"parameters", *File.template_fields}
 
     type_hint: str | None = "jupyter_notebook"
     parameters: dict | None = {}
@@ -61,7 +56,14 @@ class PapermillOperator(BaseOperator):
 
     supports_lineage = True
 
-    template_fields: Sequence[str] = ("input_nb", "output_nb", "parameters", "kernel_name", "language_name")
+    template_fields: Sequence[str] = (
+        "input_nb",
+        "output_nb",
+        "parameters",
+        "kernel_name",
+        "language_name",
+        "kernel_conn_id",
+    )
 
     def __init__(
         self,
@@ -71,6 +73,7 @@ class PapermillOperator(BaseOperator):
         parameters: dict | None = None,
         kernel_name: str | None = None,
         language_name: str | None = None,
+        kernel_conn_id: str | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -78,25 +81,40 @@ class PapermillOperator(BaseOperator):
 
         if not input_nb:
             raise ValueError("Input notebook is not specified")
-        elif not isinstance(input_nb, NoteBook):
-            self.input_nb = NoteBook(url=input_nb, parameters=self.parameters)
-        else:
-            self.input_nb = input_nb
+        self.input_nb = input_nb
 
         if not output_nb:
             raise ValueError("Output notebook is not specified")
-        elif not isinstance(output_nb, NoteBook):
-            self.output_nb = NoteBook(url=output_nb)
-        else:
-            self.output_nb = output_nb
+        self.output_nb = output_nb
 
         self.kernel_name = kernel_name
         self.language_name = language_name
-
-        self.inlets.append(self.input_nb)
-        self.outlets.append(self.output_nb)
+        self.kernel_conn_id = kernel_conn_id
 
     def execute(self, context: Context):
+        if not isinstance(self.input_nb, NoteBook):
+            self.input_nb = NoteBook(url=self.input_nb, parameters=self.parameters)
+        if not isinstance(self.output_nb, NoteBook):
+            self.output_nb = NoteBook(url=self.output_nb)
+        self.inlets.append(self.input_nb)
+        self.outlets.append(self.output_nb)
+        remote_kernel_kwargs = {}
+        kernel_hook = self.hook
+        if kernel_hook:
+            engine_name = REMOTE_KERNEL_ENGINE
+            kernel_connection = kernel_hook.get_conn()
+            remote_kernel_kwargs = {
+                "kernel_ip": kernel_connection.ip,
+                "kernel_shell_port": kernel_connection.shell_port,
+                "kernel_iopub_port": kernel_connection.iopub_port,
+                "kernel_stdin_port": kernel_connection.stdin_port,
+                "kernel_control_port": kernel_connection.control_port,
+                "kernel_hb_port": kernel_connection.hb_port,
+                "kernel_session_key": kernel_connection.session_key,
+            }
+        else:
+            engine_name = None
+
         pm.execute_notebook(
             self.input_nb.url,
             self.output_nb.url,
@@ -105,4 +123,14 @@ class PapermillOperator(BaseOperator):
             report_mode=True,
             kernel_name=self.kernel_name,
             language=self.language_name,
+            engine_name=engine_name,
+            **remote_kernel_kwargs,
         )
+
+    @cached_property
+    def hook(self) -> KernelHook | None:
+        """Get valid hook."""
+        if self.kernel_conn_id:
+            return KernelHook(kernel_conn_id=self.kernel_conn_id)
+        else:
+            return None
